==> mutual_credit-6.0.0-beta3.tar.gz: mutual_credit/modules/forms/src/McFormFunctions.php <==
<?php

namespace Drupal\mcapi_forms;
use Drupal\mcapi\Entity\WalletInterface;
use Drupal\Core\Url;

class McFormFunctions {

  /**
   * Create links to each of a wallet's payment forms, prepopulated if possible.
   *
   * Iterate through the transaction form displays and create links to ones using
   * the 'my_wallet' widget.
   *
   * @param WalletInterface $wallet
   *
   * @return array[]
   *   Items each containing a Url and string value
   */
  static function quickLinks(WalletInterface $wallet) : array {
    $links = [];
    // Put a link to specified designed forms
    $mc_forms = \Drupal::entityTypeManager()
      ->getStorage('mc_form')
      ->loadByProperties(['quicklink' => TRUE]);
    foreach ($mc_forms as $id => $mc_form) {
      /** @var Drupal\mcapi\Entity\Workflow $workflow */
      $workflow = $mc_form->getWorkflow();

      $options = [];
      if ($workflow->direction == 'bill') {
        $options['query'] = ['payer' => $wallet->id()];
      }
      else {
        $options['query'] = ['payee' => $wallet->id()];
      }

      $links[$id] = [
        'title' => str_replace('[mc_wallet:name]', $wallet->label(), $mc_form->getWalletLinkTitle()),
        'url' => Url::fromUserInput($mc_form->getPath(), $options)
      ];
    }
    return $links;
  }

  /**
   * Migration helper.
   * Get only the translated field names used in the template.
   *
   * @param string $template
   * @param string $dir
   *   outgoing, incoming or 3rdparty
   *
   * @return array
   *   The field names used in the templated, mapped to the modern names.
   */
   static function MigrateTemplateFieldMap($template) : array {
    //Get the tokens used in the old template
    preg_match_all('/\[mcapiform:([a-z_]+)\]/', $template, $matches);
    $old_tokens = $matches[1];
    unset($old_tokens[array_search('direction', $old_tokens)]);

    $mapping = [
      "payee" => "payee",
      "payer" => "payer",
      //"offers_wants_categories" => "category", // assumes smallads has upgraded & renamed the vocab..
      "transaction_description" => "description"
    ] + array_combine($old_tokens, $old_tokens);

    return $mapping;

  }

}

==> mutual_credit-6.1.0-beta3.tar.gz: mutual_credit/modules/forms/src/McFormFunctions.php <==
<?php

namespace Drupal\mcapi_forms;
use Drupal\mcapi\Entity\WalletInterface;

/**
 * Class holding miscellaneous static functions.
 */
class McFormFunctions {

  /**
   * Create links to each of a wallet's payment forms, prepopulated if possible.
   *
   * Iterate through the transaction form displays and create links to ones using
   * the 'my_wallet' widget.
   *
   * @param WalletInterface $wallet
   *
   * @return array[]
   *   Items each containing a Url and string value
   */
  static function quickLinks(WalletInterface $wallet) : array {
    $links = [];
    // Put a link to specified designed forms
    $mc_forms = \Drupal::entityTypeManager()
      ->getStorage('mc_form')
      ->loadByProperties(['quicklink' => TRUE]);
    foreach ($mc_forms as $id => $mc_form) {
      /** @var Drupal\mcapi\Entity\Workflow $workflow */
      $workflow = $mc_form->getWorkflow();
      $options = [];
      if ($workflow->isBill()) {
        $options['query'] = ['payer' => $wallet->id()];
      }
      elseif ($workflow->isCredit()) {
        $options['query'] = ['payee' => $wallet->id()];
      }

      $links[$id] = [
        'title' => str_replace('[mc_wallet:name]', $wallet->label(), $mc_form->getWalletLinkTitle()),
        'url' => $mc_form->getFormUrl($options)
      ];
    }
    return $links;
  }

  /**
   * Migration helper.
   * Get only the translated field names used in the template.
   *
   * @param string $template
   * @param string $dir
   *   outgoing, incoming or 3rdparty
   *
   * @return array
   *   The field names used in the templated, mapped to the modern names.
   */
   static function MigrateTemplateFieldMap($template) : array {
    //Get the tokens used in the old template
    preg_match_all('/\[mcapiform:([a-z_]+)\]/', $template, $matches);
    $old_tokens = $matches[1];
    unset($old_tokens[array_search('direction', $old_tokens)]);

    $mapping = [
      "payee" => "payee",
      "payer" => "payer",
      "transaction_description" => "description"
    ] + array_combine($old_tokens, $old_tokens);

    return $mapping;

  }

}
